@@ -12,12 +12,13 @@
 #    under the License.
 
 import os
+import requests
+import subprocess
 import time
 import uuid
 
 import concurrent.futures
 from oslo_config import cfg
-import six.moves
 from testtools import matchers
 
 import oslo_messaging
@@ -535,7 +536,7 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
                                            batch_timeout=batch_timeout))
         notifier = listener.notifier('abc')
 
-        for i in six.moves.range(0, 205):
+        for i in range(0, 205):
             notifier.info({}, 'test%s' % i, 'Hello World!')
         events = listener.get_events(timeout=get_timeout)
         self.assertEqual(3, len(events))
@@ -566,3 +567,35 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
         self.assertEqual('test', event[1])
         self.assertEqual('Hello World!', event[2])
         self.assertEqual('abc', event[3])
+
+
+class MetricsTestCase(utils.SkipIfNoTransportURL):
+
+    def setUp(self):
+        super(MetricsTestCase, self).setUp(conf=cfg.ConfigOpts())
+        if self.rpc_url.startswith("kafka://"):
+            self.skipTest("kafka does not support RPC API")
+
+        self.config(metrics_enabled=True,
+                    group='oslo_messaging_metrics')
+
+    def test_functional(self):
+        # verify call metrics is sent and reflected in oslo.metrics
+        self.config(metrics_socket_file='/var/tmp/metrics_collector.sock',
+                    group='oslo_messaging_metrics')
+        metric_server = subprocess.Popen(["python3", "-m", "oslo_metrics"])
+        time.sleep(1)
+        group = self.useFixture(
+            utils.RpcServerGroupFixture(self.conf, self.rpc_url))
+        client = group.client(1)
+        client.add(increment=1)
+        time.sleep(1)
+        r = requests.get('http://localhost:3000')
+        for line in r.text.split('\n'):
+            if 'client_invocation_start_total{' in line:
+                self.assertEqual('1.0', line[-3:])
+            elif 'client_invocation_end_total{' in line:
+                self.assertEqual('1.0', line[-3:])
+            elif 'client_processing_seconds_count{' in line:
+                self.assertEqual('1.0', line[-3:])
+        metric_server.terminate()
